@@ -15,29 +15,61 @@ DBD::Unify - DBI driver for Unify database systems
 
 =head1 SYNOPSIS
 
+ # Examples marked NYT are Not Yet Tested, they might work
+ #  all others have been tested.
+ # man DBI for explanation of each method
+
  $dbh = DBI->connect ("DBI:Unify:[\$dbname]", "", $schema, {
 			 AutoCommit => 0,
 			 ChopBlanks => 1,
 			 ScanLevel  => 2,
 			 });
+ $dbh = DBI->connect_cached (...);                   # NYT
  $dbh->do ($statement);
- $dbh->commit ();
- $dbh->rollback ();
- $dbh->disconnect ();
+ $dbh->do ($statement, \%attr);                      # NYT
+ $dbh->do ($statement, \%attr, @bind);               # NYT
+ $dbh->commit;
+ $dbh->rollback;
+ $dbh->disconnect;
 
+ $all = $dbh->selectall_arrayref ($statement);
  @row = $dbh->selectrow_array ($statement);
+ $col = $dbh->selectcol_arrayref ($statement);
 
  $sth = $dbh->prepare ($statement);
- $sth->execute ();
- @row = $sth->fetchrow_array ();
- $sth->finish ();
+ $sth = $dbh->prepare_cached ($statement);           # NYT
+ $sth->execute;
+ @row = $sth->fetchrow_array;
+ $row = $sth->fetchrow_arrayref;
+ $row = $sth->fetchrow_hashref;
+ $all = $sth->fetchall_arrayref;
+ $sth->finish;
 
  # Statement has placeholders like where field = ?
  $sth = $dbh->prepare ($statement);
+ $sth->bind_param ($p_num, $bind_value);             # NYT
+ $sth->bind_param ($p_num, $bind_value, $bind_type); # NYT
+ $sth->bind_param ($p_num, $bind_value, \%attr);     # NYT
+ $sth->bind_col ($col_num, \$col_variable);          # NYT
+ $sth->bind_columns (@list_of_refs_to_vars_to_bind);
  $sth->execute (3);
- @row = $sth->fetchrow_array ();
- $sth->finish ();
- ...
+ @row = $sth->fetchrow_array;
+ $sth->finish;
+
+ $cnt = $sth->rows;                                  # NYT
+
+ $sql = $dbh->quote ($string);
+
+ $err = $dbh->err;
+ $err = $sth->err;
+ $str = $dbh->errstr;
+ $str = $sth->errstr;
+ $stt = $dbh->state;
+ $stt = $sth->state;
+
+ For large DB fetches the combination $sth->bind_columns ()
+ with $sth->fetchrow_arrayref is the fastest (DBI
+ documentation).
 
 =cut
 
@@ -51,7 +83,7 @@ use DBI 1.12;
 use DynaLoader ();
 
 use vars qw(@ISA $VERSION);
-$VERSION = "0.07";
+$VERSION = "0.10";
 
 @ISA = qw(DynaLoader);
 bootstrap DBD::Unify $VERSION;
@@ -134,6 +166,7 @@ $DBD::Unify::db::imp_data_size = 0;
 sub do
 {
     my ($dbh, $statement, $attribs, @params) = @_;
+    # Next two might use base class: DBD::_::do (@_);
     Carp::carp "DBD::Unify::\$dbh->do () attribs unused\n" if $attribs;
     Carp::carp "DBD::Unify::\$dbh->do () params unused\n"  if @params;
     DBD::Unify::db::_do ($dbh, $statement);
@@ -143,6 +176,12 @@ sub prepare
 {
     my ($dbh, $statement, @attribs) = @_;
 
+    # Strip comments
+    $statement = join "" => map {
+	my $s = $_;
+	$s =~ m/^'.*'$/ or $s =~ s/(--.*)$//m;
+	$s;
+	} split m/('[^']*')/ => $statement;
     # create a 'blank' sth
     my $sth = DBI::_new_sth ($dbh, {
 	Statement => $statement,
@@ -161,21 +200,22 @@ sub prepare
 sub table_info
 {
     my ($dbh) = @_;
-    my $sth = $dbh->prepare ("select * from SYS.ACCESSIBLE_TABLES");
+    my $sth = $dbh->prepare (
+	"select '', OWNR, TABLE_NAME, TABLE_TYPE, RDWRITE ".
+	"from   SYS.ACCESSIBLE_TABLES");
     $sth or return;
     $sth->execute ();
     $sth;
     } # table_info
 
-#sub ping
-#{
-#    my ($dbh) = @_;
-#    # we know that DBD::Unify prepare does a describe so this will
-#    # actually talk to the server and is this a valid and cheap test.
-#    return 1 if $dbh->prepare ("tables");
-#    return 0;
-#    } # ping
+sub ping
+{
+    my $dbh = shift;
+    $dbh->prepare ("select * from SYS.UNIQ") or return 0;
+    return 1;
+    } # ping
 
+# STORE and FETCH are implemented in dbdimp.ic
 sub STOREx
 {
     my ($dbh, $attr, $val) = @_;
@@ -207,7 +247,7 @@ sub FETCHx
     # ScanLevel can be changed with $dbh->do (), so this is not very reliable
     $attr eq "ScanLevel"		and return $dbh->{$attr};
 
-    $dbh->SUPER::FETCH ($attr);
+    DBD::Unify::st::_FETCH ($dbh, $attr);
     } # FETCH
 
 1;
